#include "systick.h"
#include <util/atomic.h>
#include <avr/io.h>
#include <avr/interrupt.h>

static volatile uint32_t counter = 0;

ISR (TIMER1_COMPA_vect)
{
    counter++;
}

void systick_init(uint16_t period)
{
    // CTC mode, Clock/8
    TCCR1B |= (1 << WGM12) | (1 << CS11);

	uint16_t match = (F_CPU / 1000 * period) / 8;
    // Load the high byte, then the low byte into the output compare
    OCR1AH = (match >> 8);
    OCR1AL = match & 0xFF;

    // Enable the compare match interrupt
    TIMSK |= (1 << OCIE1A);	
}

uint32_t systick_val(void)
{
	uint32_t copy;
	ATOMIC_BLOCK(ATOMIC_FORCEON)
	{
		copy = counter;
	}
	return copy;
}

void systick_reset(void)
{
	ATOMIC_BLOCK(ATOMIC_FORCEON)
	{
		counter = 0;
	}
}
